==> gradle-8.8-all.zip: gradle-8.8/src/dependency-management/org/gradle/internal/component/model/GraphSelectionCandidates.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.component.model;

import org.gradle.api.artifacts.Dependency;

import javax.annotation.Nullable;
import java.util.List;

public interface GraphSelectionCandidates {
    /**
     * Should variant selection be used?
     * @return true when variant selection should be used, false when the legacy variant should be used.
     */
    boolean isUseVariants();

    /**
     * Returns the set of variants to select from. Should only be called when {@link #isUseVariants()} returns true.
     */
    List<? extends VariantGraphResolveState> getVariants();

    /**
     * Returns the variant to use when attribute-based variant selection is not enabled.
     */
    @Nullable
    default VariantGraphResolveState getLegacyVariant() {
        return getVariantByConfigurationName(Dependency.DEFAULT_CONFIGURATION);
    }

    /**
     * Returns the variant that is identified by the given configuration name.
     */
    @Nullable
    VariantGraphResolveState getVariantByConfigurationName(String name);
}

==> gradle-8.9-all.zip: gradle-8.9/src/dependency-management/org/gradle/internal/component/model/GraphSelectionCandidates.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.component.model;

import org.gradle.api.artifacts.Dependency;
import org.gradle.internal.component.ResolutionFailureHandler;

import javax.annotation.Nullable;
import java.util.List;

public interface GraphSelectionCandidates {

    /**
     * Returns the set of variants to select from during attribute matching, or an empty list of this
     * component does not support attribute matching.
     */
    List<? extends VariantGraphResolveState> getVariantsForAttributeMatching();

    /**
     * Returns the variant to use when attribute-based variant selection is not enabled.
     */
    @Nullable
    default VariantGraphResolveState getLegacyVariant(ResolutionFailureHandler failureHandler) {
        return getVariantByConfigurationName(Dependency.DEFAULT_CONFIGURATION, failureHandler);
    }

    /**
     * Returns the variant that is identified by the given configuration name.
     */
    @Nullable
    VariantGraphResolveState getVariantByConfigurationName(String name, ResolutionFailureHandler failureHandler);
}
